import pandas as pd
from matplotlib import pyplot as plt
from string import capwords

from os.path import dirname, abspath

PATH = '%s/' % (dirname(abspath(__file__)),)

NAME_DISTRIBUTIONS = pd.read_csv(PATH + '../datasets/NameDistributions.csv', index_col=[0,1])
VALID_NAMES = set(NAME_DISTRIBUTIONS.index.levels[0])
SEX_DISTRIBUTIONS = pd.read_csv(PATH + '../datasets/SexDistributions.csv', index_col=[0,1])
US_AGE = pd.read_csv(PATH + '../datasets/US Age Dist.csv', index_col=[0])


def age_calculator(name_frequencies):
    prob = 0.
    for name, freq in name_frequencies.iteritems():
        try:
            prob += NAME_DISTRIBUTIONS.ix[name]*freq
        except:
            pass
    return prob

def sex_calculator(name_frequencies):
    prob = 0.
    for name, freq in name_frequencies.iteritems():
        try:
            prob += SEX_DISTRIBUTIONS.ix[name]*freq
        except KeyError as e:
            pass
    return prob

def compute_name_frequencies(names):
    """
    Parameters:
        names: a list or iterable of first names
    """

    data = pd.Series(names).map(capwords)
    data = data.ix[data.map( lambda r: r in VALID_NAMES )]
    data_normalized = data.groupby(data.values).count()/data.shape[0]
    return data_normalized

def pplot(age_distribution, label='Inferred age distribution', plot_US_age=True):
    ax = age_distribution['probability'].plot(rot=25, label=label)
    ax.set_ylabel('Percent')
    ax.set_xlabel('Age')
    ax.set_title('Age Distribution')

    if plot_US_age:
        ax = US_AGE['probability'].plot(ax=ax, rot=25, label='US age distribution')

    ax.legend()
    return ax

if __name__=="__main__":
    names = pd.read_csv(PATH + '../datasets/sample_first_names.tsv', delimiter="\t")['first_name']
    names = names.ix[pd.notnull(names)]

    name_distribution = compute_name_frequencies(names)

    age_distribution = age_calculator(name_distribution)
    sex_distribution = sex_calculator(name_distribution)

    print names.head(10)
    print
    print age_distribution
    print
    print sex_distribution

    # plotting 
    # pplot(age_distribution)



#!/usr/bin/env python

import sys
import os
from setuptools import setup

DESC = """A Python Package to infer ages using US Census Data"""

setup(
    name="demographica",
    version='0.1.4',
    description=DESC,
    long_description=DESC,
    author="Cameron Davidson-Pilon",
    author_email="cam.davidson.pilon@gmail.com",
    license="MIT",
    packages=["demographica"],
    url="https://github.com/CamDavidsonPilon/demographica",
    install_requires=["numpy", "pandas>=0.14", "matplotlib"],
    classifiers=[
        "Development Status :: 4 - Beta",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Topic :: Scientific/Engineering",
    ],
)



import glob
import datetime
import string

import pandas as pd


def age_binner(age):
    if age < 5:
        return "04 and under"
    elif 5 <= age <= 9:
        return "05 to 09 years" 
    elif 10 <= age <= 14:
        return "10 to 14 years" 
    elif 15 <= age <= 19:
        return "15 to 19 years" 
    elif 20 <= age <= 24:
        return "20 to 24 years" 
    elif 25 <= age <= 29:
        return "25 to 29 years" 
    elif 30 <= age <= 34:
        return "30 to 34 years" 
    elif 35 <= age <= 39:
        return "35 to 39 years" 
    elif 40 <= age <= 44:
        return "40 to 44 years" 
    elif 45 <= age <= 49:
        return "45 to 49 years" 
    elif 50 <= age <= 54:
        return "50 to 54 years" 
    elif 55 <= age <= 59:
        return "55 to 59 years" 
    elif 60 <= age <= 64:
        return "60 to 64 years" 
    elif 65 <= age <= 69:
        return "65 to 69 years" 
    elif 70 <= age <= 74:
        return "70 to 74 years" 
    elif 75 <= age <=79:
        return "75 to 79 years" 
    elif 80 <= age <=84:
        return "80 to 84 years" 
    else:
        return "85 years and over"

